==> user_referral-2.0.1.tar.gz: user_referral/tests/src/Traits/UserReferralTypeTestTrait.php <==
<?php

namespace Drupal\Tests\user_referral\Traits;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\user_referral\Entity\UserReferralType;
use PHPUnit\Framework\TestCase;

/**
 * Provides methods to create user referral type from given values.
 *
 * This trait is meant to be used only by test classes.
 */
trait UserReferralTypeTestTrait {

  /**
   * Creates a custom user referral type based on default settings.
   *
   * @param array $values
   *   An array of settings to change from the defaults.
   *   Example: 'type' => 'foo'.
   *
   * @return \Drupal\user_referral\Entity\UserReferralType
   *   Created user referral type.
   */
  protected function createUserReferralType(array $values = []) {
    // Find a non-existent random type name.
    if (!isset($values['type'])) {
      do {
        $id = strtolower($this->randomMachineName(8));
      } while (UserReferralType::load($id));
    }
    else {
      $id = $values['type'];
    }
    $values += [
      'type' => $id,
      'name' => $id,
    ];
    $type = UserReferralType::create($values);
    $status = $type->save();
    // node_add_body_field($type);

    if ($this instanceof TestCase) {
      $this->assertSame($status, SAVED_NEW, (new FormattableMarkup('Created user referral type %type.', ['%type' => $type->id()]))->__toString());
    }
    else {
      $this->assertEqual($status, SAVED_NEW, (new FormattableMarkup('Created user referral type %type.', ['%type' => $type->id()]))->__toString());
    }

    return $type;
  }

  protected function getReferralCookie() {
    $assert_session = $this->assertSession();
    $assert_session->cookieExists(UserReferralType::COOKIE_NAME);
    return json_decode($this->getSession()->getCookie(UserReferralType::COOKIE_NAME));
  }

  protected function assertReferralCookie($referrer_uid, $referral_type_name) {
    $assert_session = $this->assertSession();
    $assert_session->cookieExists(UserReferralType::COOKIE_NAME);
    $referral_cookie = json_decode($this->getSession()->getCookie(UserReferralType::COOKIE_NAME));
    $this->assertEqual($referral_cookie->uid, $referrer_uid, t('Referrer UID matches in cookied'));
    $this->assertEqual($referral_cookie->type, $referral_type_name, t('Referral type matches in cookie'));
  }

}

==> user_referral-3.1.1.tar.gz: user_referral/tests/src/Traits/UserReferralTypeTestTrait.php <==
<?php

namespace Drupal\Tests\user_referral\Traits;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\user_referral\Entity\UserReferralType;
use PHPUnit\Framework\TestCase;

/**
 * Provides methods to create user referral type from given values.
 *
 * This trait is meant to be used only by test classes.
 */
trait UserReferralTypeTestTrait {

  /**
   * Creates a custom user referral type based on default settings.
   *
   * @param array $values
   *   An array of settings to change from the defaults.
   *   Example: 'type' => 'foo'.
   *
   * @return \Drupal\user_referral\Entity\UserReferralType
   *   Created user referral type.
   */
  protected function createUserReferralType(array $values = []) {
    // Find a non-existent random type name.
    if (!isset($values['type'])) {
      do {
        $id = strtolower($this->randomMachineName(8));
      } while (UserReferralType::load($id));
    }
    else {
      $id = $values['type'];
    }
    $values += [
      'type' => $id,
      'name' => $id,
    ];
    $type = UserReferralType::create($values);
    $status = $type->save();
    // node_add_body_field($type);

    if ($this instanceof TestCase) {
      $this->assertSame($status, SAVED_NEW, (new FormattableMarkup('Created user referral type %type.', ['%type' => $type->id()]))->__toString());
    }
    else {
      $this->assertEquals($status, SAVED_NEW, (new FormattableMarkup('Created user referral type %type.', ['%type' => $type->id()]))->__toString());
    }

    return $type;
  }

  protected function getReferralCookie() {
    $assert_session = $this->assertSession();
    $assert_session->cookieExists(UserReferralType::COOKIE_NAME);
    return json_decode($this->getSession()->getCookie(UserReferralType::COOKIE_NAME));
  }

  protected function assertReferralCookie($referrer_uid, $referral_type_name) {
    $assert_session = $this->assertSession();
    $assert_session->cookieExists(UserReferralType::COOKIE_NAME);
    $referral_cookie = json_decode($this->getSession()->getCookie(UserReferralType::COOKIE_NAME));
    $this->assertEquals($referral_cookie->uid, $referrer_uid, t('Referrer UID matches in cookied'));
    $this->assertEquals($referral_cookie->type, $referral_type_name, t('Referral type matches in cookie'));
  }

}
